===================
Credits and License
===================

Main Contributors
=================
* Marshall Wang (https://github.com/XkunW)
* Thomas Jiralerspong (https://github.com/superkaiba)
* John Willes (https://github.com/jwilles)

License
=======
The code in this repository is published under 3-Clause BSD license (see ``LICENSE`` file).